%-----------------------------------------------------------------------------
%
%               LaTeX Class/Style File
%
% Name:         uulmcover
%
% Purpose:      Cover sheet for seminars (Seminar/Proseminar) in computer science at Ulm Unversity
%        
% Creator:      Birte Glimm
% 
% Source:       The cover sheet is based on the template 
%               "Charité - Universitätsmedizin Berlin Repository Cover Sheet Template"
%               von Thomas Vogel, Steffi Grimm, Elena Gandert (June 2019)
%               der Charité Medical Library 
%               https://www.overleaf.com/latex/templates/charite-universitatsmedizin-berlin-repository-cover-sheet-template/bypqttrsbjmn
%
% Created:      Aug 2021
%
%-----------------------------------------------------------------------------


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{uulmcover}[2021/08/11 Template for cover sheets For seminars in computer science at Ulm University]

%% Options
% Language
\DeclareOption{english}	 {
	\def \UUlmSeminarDeckblatt@matriculationNoHeader{Matriculation Number}
	\def \UUlmSeminarDeckblatt@seminarHeader{Seminar}
	\def \UUlmSeminarDeckblatt@semesterHeader{Semester}
	\def \UUlmSeminarDeckblatt@supervisorHeader{Supervisor}
}
\DeclareOption{german}	 {
	\def \UUlmSeminarDeckblatt@matriculationNoHeader{Matrikelnummer}
	\def \UUlmSeminarDeckblatt@seminarHeader{Seminar}
	\def \UUlmSeminarDeckblatt@semesterHeader{Semester}
	\def \UUlmSeminarDeckblatt@supervisorHeader{Betreuer} 
}
	

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}

\ExecuteOptions{german}
\ProcessOptions
\relax

\LoadClass[oldfontcommands, extrafontsizes, a4paper, oneside]{memoir}

%% Packages
\RequirePackage{xspace}
\RequirePackage{pdfpages}
\RequirePackage{graphicx}

%% Standalone
\RequirePackage{standalone}

%% Encoding
\RequirePackage[utf8]{inputenx}
\RequirePackage[T1]{fontenc}

%% Fonts and typography
\RequirePackage{lmodern}           % Latin Modern
\renewcommand{\sfdefault}{phv}     % Helvetica
\RequirePackage[scaled]{beramono}  % Bera Mono (Bitstream Vera Sans Mono)
\RequirePackage[final]{microtype}  % Improved typography


%% Layout
\usepackage[a4paper]{geometry} % showframe

% Paper size
% offsets
\hoffset=-1in
\voffset=-1in

% text area
\textwidth=166mm
\textheight=253mm

% header
\topmargin=22mm
\headsep=0mm
\headheight=0mm

% left margin
\oddsidemargin=22mm
\marginparpush=0mm

% right margin
\marginparwidth=0mm
\marginparsep=0mm

% footer
\footskip=0mm

% center without vspaces
\newenvironment{novspacecenter}
{\parskip=0pt\par\nopagebreak\hspace*{9cm}}
{\par\noindent\ignorespacesafterend}


%% Title page
\newcommand{\uulmtitle}
{
    \begin{titlingpage}
        	\begin{novspacecenter}
        		\includegraphics[width=73mm]{logo}
        	\end{novspacecenter}
            \vskip19mm
	        \raggedright
            \vskip18mm
             {
				\fontsize{22}{26.4}
				\bfseries
				\boldmath
				\sffamily
				\thetitle
				\par
            }
        	\ifx\UUlmSeminarDeckblatt@subtitle\empty
        		% no subtitle
        	\else
	            \vskip2\onelineskip
		        {
					\fontsize{20}{24}
					\boldmath
					\sffamily
					\UUlmSeminarDeckblatt@subtitle
					\par
		        }
	        \fi
            \vskip2.5\onelineskip
            {%
				\fontsize{15}{18}
				\boldmath
				\sffamily
				\theauthor
				\par
            }
            \vfill
            {
	            \large
	            %\fontsize{10}{12}
	            \sffamily
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				\ifx\UUlmSeminarDeckblatt@matriculationNo\empty
					% no matriculation number given
				\else
					\vskip1.5\onelineskip
					\textbf{\UUlmSeminarDeckblatt@matriculationNoHeader}\par
					\UUlmSeminarDeckblatt@matriculationNo
				\fi
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
               	\ifx\UUlmSeminarDeckblatt@seminar\empty
               		% no seminar name given
               	\else
               		\vskip1.5\onelineskip
               		\textbf{\UUlmSeminarDeckblatt@seminarHeader}\par
               		\UUlmSeminarDeckblatt@seminar
               	\fi
               	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
               	\ifx\UUlmSeminarDeckblatt@supervisor\empty
               		% no supervisor Name given
               	\else
               	\vskip1.5\onelineskip
               	\textbf{\UUlmSeminarDeckblatt@supervisorHeader}\par
               	\UUlmSeminarDeckblatt@supervisor
               	\fi
               	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
               	\ifx\UUlmSeminarDeckblatt@semester\empty
               		% no semester given
               		\vskip1.5\onelineskip
               	\else
               		\vskip1.5\onelineskip
               	   	\textbf{\UUlmSeminarDeckblatt@semesterHeader}\par
			   		\UUlmSeminarDeckblatt@semester
                \fi
                
				\vskip1\onelineskip
            }
    \end{titlingpage}
}


%% User-specified data
\newcommand{\subtitle}[1]{ \def \UUlmSeminarDeckblatt@subtitle{#1} }
\subtitle{}

\newcommand{\affiliation}[1]{ \def \UUlmSeminarDeckblatt@affiliation{#1} }
\affiliation{}

\newcommand{\matriculationNo}[1]{ \def \UUlmSeminarDeckblatt@matriculationNo{#1} }
\matriculationNo{}

\newcommand{\seminar}[1]{ \def \UUlmSeminarDeckblatt@seminar{#1} }
\seminar{}

\newcommand{\supervisor}[1]{ \def \UUlmSeminarDeckblatt@supervisor{#1} }
\supervisor{}

\newcommand{\semester}[1]{ \def \UUlmSeminarDeckblatt@semester{#1} }
\semester{}

%%%%%%%%%%%%%%
\endinput
